==> haskell-resourcet-1.2.2-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.2.2
id: resourcet-1.2.2-5WRYEUs9Kel3m2rSVevxcM
key: resourcet-1.2.2-5WRYEUs9Kel3m2rSVevxcM
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
abi: c200bbbcd898c4e98b8c23134bb0fa42
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource
import-dirs: /usr/lib/ghc-8.6.4/site-local/resourcet-1.2.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/resourcet-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/resourcet-1.2.2
hs-libraries: HSresourcet-1.2.2-5WRYEUs9Kel3m2rSVevxcM
depends:
    base-4.12.0.0 containers-0.6.0.1
    exceptions-0.10.0-HSEN1HsF9E42usfcjSNYsT mtl-2.2.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b transformers-0.5.6.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resourcet-1.2.2-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.2.2
id: resourcet-1.2.2-1SMNkPIB95cIP5fLPJeWPc
key: resourcet-1.2.2-1SMNkPIB95cIP5fLPJeWPc
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
abi: 792002a9e3056e45a300db423bbe2568
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource
import-dirs: /usr/lib/ghc-8.6.4/site-local/resourcet-1.2.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/resourcet-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/resourcet-1.2.2
hs-libraries: HSresourcet-1.2.2-1SMNkPIB95cIP5fLPJeWPc
depends:
    base-4.12.0.0 containers-0.6.0.1
    exceptions-0.10.1-7nkghZ77rTO8NZKanvk3XU mtl-2.2.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b transformers-0.5.6.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
